Method: PreCommit.checks_to_run
- Defined in:
- lib/pre-commit.rb
.checks_to_run ⇒ Object
Can not delete this method with out a deprecation strategy. It is refered to in the generated pre-commit hook in versions 0.0-0.1.1
NOTE: The deprecation strategy may be just delete it since, we’re still pre 1.0.
Actually, on the deprecation note. This method isn’t really the problem. The problem is the default generated pre-commit hook. It shouldn’t have logic in it. The we have freedom to change the gem implementation however we want, and nobody is forced to update their pre-commit binary.
18 19 20 21 |
# File 'lib/pre-commit.rb', line 18 def self.checks_to_run warn "WARNING: You are using old hook version, you can update it with: pre-commit install" runner.list_to_run(:checks) end |